==> moodle-1.9.5.tbz: www/moodle/grade/report/grader/styles.php <==
.flexible th {
white-space:normal;
}

.gradestable th.user img {
width:20px;
height:20px;
}

.grade-report-grader table#user-grades .catlevel2 {
background-color:#f9f9f9;
}

.grade-report-grader table#user-grades td.overridden {
background-color:#ddd;
}

.grade-report-grader table#user-grades tr.avg td.cell {
background-color:#efefff;
font-weight:700;
color:#00008B;
}

.grade-report-grader table#user-grades tr.odd td.cell {
background-color:#efefef;
white-space:nowrap;
}

.grade-report-grader table#user-grades tr.even td.overridden {
background-color:#F3E4C0;
}

.grade-report-grader table#user-grades tr.odd td.overridden {
background-color:#EFD9A4;
}

.grade-report-grader table#user-grades tr.even td.excluded {
background-color:#EABFFF;
}

.grade-report-grader table#user-grades tr.odd td.excluded {
background-color:#E5AFFF;
}

.grade-report-grader table#user-grades tr.odd th.header {
background-color:#efefef;
background-image:none;
}

.grade-report-grader table#user-grades tr.groupavg td.cell {
background-color:#efffef;
font-weight:700;
color:#006400;
}

.grade-report-grader table#user-grades td.cat,.grade-report-grader table#user-grades td.course {
font-weight:700;
}

.grade-report-grader table#user-grades {
font-size:10px;
width:auto;
background-color:transparent;
border-style:solid;
border-width:1px;
margin:20px 0 0;
}

.grade-report-grader #overDiv table {
margin:0;
}

.grade-report-grader #overDiv table td.feedback {
border:0;
}

.grade-report-grader #overDiv .feedback {
font-size:70%;
background-color:#ABF;
color:#000;
font-family:Verdana;
font-weight:400;
}

.grade-report-grader #overDiv .caption {
font-size:70%;
background-color:#56C;
color:#CCF;
font-family:Arial;
font-weight:700;
}

.grade-report-grader #overDiv .intersection {
font-size:70%;
background-color:#ABF;
color:#000;
font-family:Verdana;
font-weight:400;
}

.grade-report-grader #overDiv .intersectioncaption {
background-color:#56C;
color:#CCF;
font-family:Arial;
font-weight:700;
}

.grade-report-grader div.submit {
margin-top:20px;
text-align:center;
}

.grade-report-grader table#user-grades td {
text-align:right;
border-style:solid;
border-width:0 1px 1px 0;
}

.grade-report-grader table#user-grades th.category {
vertical-align:top;
border-style:solid;
border-width:1px 1px 0;
}

.grade-report-grader table#user-grades th.user {
text-align:left;
border-style:solid;
border-width:0 0 1px;
}

.grade-report-grader table#user-grades th.useridnumber {
border-style:solid;
border-width:0 0 1px 1px;
}

.grade-report-grader table#user-grades th.categoryitem,.grade-report-grader table#user-grades th.courseitem,.grade-report-grader table#user-grades td.topleft {
vertical-align:top;
border-style:solid;
border-width:0 1px;
}

.grade-report-grader table#user-grades th.category,
.grade-report-grader table#user-grades th.item,
.grade-report-grader table#user-grades th.categoryitem,
.grade-report-grader table#user-grades th.courseitem {
height: 25px;
}

.grade-report-grader td,.grade-report-grader th {
border-color:#CECECE;
}

.grade-report-grader table#participants th {
vertical-align:top;
width:auto;
}

.grade-report-grader table#user-grades td.fillerfirst {
border-style:solid;
border-width:0 0 0 1px;
}

.grade-report-grader table#user-grades td.fillerlast {
border-style:solid;
border-width:0 1px 0 0;
}

.grade-report-grader table#user-grades th.item ,
.grade-report-grader table#user-grades th.categoryitem ,
.grade-report-grader table#user-grades th.courseitem {
border-bottom-color:#000;
vertical-align:top;
border-style:solid;
border-width:1px;
}

.grade-report-grader div.gradertoggle {
display:inline;
margin-left:20px;
}

.grade-report-grader table#user-grades th.range {
text-align:right;
border-style:solid;
border-width:1px;
}

.grade-report-grader table#user-grades .userpic {
display:inline;
margin-right:10px;
}

.grade-report-grader table#user-grades .quickfeedback {
border:#000 1px dashed;
}

.grade-report-grader #siteconfiglink {
text-align:right;
}

.grade-report-grader table#user-grades .hidden,.grade-report-grader table#user-grades .hidden a {
color:#aaa;
}

.grade-report-grader table#user-grades .datesubmitted {
font-size:.7em;
}

.grade-report-grader table#user-grades td.cell {
padding-left:5px;
padding-right:5px;
vertical-align:middle;
}

.grade-report-grader table {
border-collapse:collapse;
background-color:#fff;
font-size:10px;
border-color:#cecece;
}

.grade-report-grader th {
padding:2px 10px 0;
}

.grade-report-grader span.inclusion-links {
margin:0 5px 0 10px;
}

.grade-report-grader table#user-grades .item {
background-color:#e9e9e9;
}

.grade-report-grader table tr.odd th.header {
background-color:#efefef;
background-image:none;
border-width:0 0 1px;
}

.grade-report-grader table tr.heading th.header {
border-top:1px solid #cecece;
}

.grade-report-grader table#user-grades tr.heading th.categoryitem,.grade-report-grader table#user-grades tr.heading th.courseitem {
border-width:0 0 0 1px;
}

.grade-report-grader table#user-grades th.category.header.catlevel1 {
vertical-align:top;
border-style:solid;
border-width:1px 1px 0 0;
}

.grade-report-grader div.left_scroller th.user a {
vertical-align:middle;
margin:0;
padding:0;
}

.grade-report-grader table#user-grades th.categoryitem,.grade-report-grader table#user-grades th.courseitem,.grade-report-grader table td.topleft {
vertical-align:top;
border-color:#cecece #cecece #000;
border-style:solid;
border-width:0 1px 1px;
}

.grade-report-grader table td.topleft {
border-bottom:none;
}

.grade-report-grader table#user-grades td.topleft {
background-color:#fff;
}

.grade-report-grader div.userpic {
margin-right:10px;
float:left;
}

.grade-report-grader div.userpic img {
border:3px double #cecece;
vertical-align:middle;
width:2.7em;
height:2.7em;
}

.grade-report-grader a.quickedit {
line-height:1em;
display:block;
float:right;
clear:none;
font-size:9px;
background-color:transparent;
margin:.1em 0 0;
}

.grade-report-grader a.quickedit2 {
display:block;
float:right;
clear:none;
background-color:transparent;
margin:1.3em 0 0;
}

.grade-report-grader table#quick_edit {
border:1px solid #cecece;
margin:0 auto;
}

.grade-report-grader table#quick_edit td {
vertical-align:middle;
border:1px solid #cecece;
text-align:left;
margin:0;
padding:5px;
}

.grade-report-grader table#quick_edit td img {
border:3px double #cecece;
vertical-align:middle;
padding:0;
}

.grade-report-grader td input {
border:1px solid #666;
margin-left:10px;
margin-right:10px;
}

.grade-report-grader table#quick_edit td.fullname {
border-left:none;
padding-left:5px;
}

.grade-report-grader table#quick_edit td.picture {
border-right:none;
}

.grade-report-grader table#quick_edit td.finalgrade input {
width:5em;
}

.grade-report-grader h1 {
text-align:center;
clear:both;
}

.grade-report-grader form {
text-align:center;
}

.grade-report-grader input.center {
margin:10px auto 0;
}

.grade-report-grader .lefttbody {
width:auto;
vertical-align:middle;
}

.grade-report-grader table#user-grades th.fixedcolumn {
border:1px solid #cecece;
vertical-align:middle;
}

.grade-report-grader table#fixed_column th {
border:1px solid #cecece;
vertical-align:middle;
border-right-color:#000;
}

.grade-report-grader table#fixed_column {
padding-top:20px;
border-top:1px solid #cecece;
background-color:#fff;
}

.grade-report-grader .left_scroller {
float:left;
clear:none;
padding-top:20px;
}

.grade-report-grader .right_scroller {
width:auto;
clear:none;
overflow-x:auto;
}

.grade-report-grader table tr.avg,.grade-report-grader table tr.groupavg td,.grade-report-grader table tr.avg td,.grade-report-grader table tr.groupavg th,.grade-report-grader table tr.avg th,.grade-report-grader table tr.controls_row,.grade-report-grader table tr.controls_row th,.grade-report-grader table tr.range_row,.grade-report-grader table tr.range_row th,div.right_scroller tr {
height:2em;
}

.grade-report-grader table#user-grades tr.groupavg td.cell,.grade-report-grader tr.groupavg th.header {
background-color:#efffef;
}

.grade-report-grader form td.excluded {
color:red;
}

.grade-report-grader .excludedfloater {
font-weight:700;
color:red;
font-size:9px;
float:left;
}

.grade-report-grader span.gradepass {
color:#298721;
}

.grade-report-grader span.gradefail {
color:#890d0d;
}

.gradeweight {
color:#461d7c;
font-weight:700;
}

.grade-report-grader td select {
font-size:100%;
padding:0;
}

.grade-report-grader .righttest td select {
font-size:86%;
padding:0;
}

.grade-report-grader tr.avg,tr.controls,td.controls,th.controls,.grade-report-grader tr.groupavg,tr.range,th.range,td.range,tr.heading th.range {
height:2em!important;
white-space:nowrap;
}

.heading_name_row th {
white-space:nowrap;
width:2000px;
}

.ie .right_scroller {
padding-bottom:15px;
overflow-y:hidden;
}

.ie table#fixed_column th {
height:40.5px;
}

.ie table#fixed_column tr.avg th {
height:21px;
}

.ie div.left_scroller td {
height:42px;
}

.ie6 div.left_scroller {
margin-top:40px;
}

.ie6 div.right_scroller {
margin-top:40px;
width:auto;
position:absolute;
}

.ie6 .excludedfloater {
font-size:7px;
}

.grade_icons img.ajax {
float:right;
}

.gradestable th.user,.gradestable th.range,.grade-report-grader .flexible th,.grade-report-grader .flexible td,.grade-report-grader .flexible th a,.grade-report-grader .flexible td a,.grade-report-grader .gradestable th.range,.grade-report-grader td {
white-space:nowrap;
}

.grade-report-grader table#user-grades .catlevel1,.grade-report-grader .r1,.grade-report-grader table tr.even td.cell,.grade-report-grader table tr.even th {
background-color:#fff;
}

.grade-report-grader table#user-grades .catlevel3,.grade-report-grader table tr.odd td.cell {
background-color:#efefef;
}

.grade-report-grader table#fixed_column tr.odd th ,
.grade-report-grader table#user-grades tr.odd th {
background-color:#efefef;
}

.grade-report-grader table#user-grades td.vmarked,.grade-report-grader table#user-grades tr.odd td.vmarked,.grade-report-grader table#user-grades td.vmarked,.grade-report-grader table#user-grades tr.odd td.vmarked,.grade-report-grader table#user-grades tr.even td.vmarked {
background-color:#fc3;
}

.grade-report-grader table#user-grades td.hmarked,.grade-report-grader table#user-grades tr.odd td.hmarked,.grade-report-grader table#user-grades td.hmarked,.grade-report-grader table#user-grades tr.odd td.hmarked,.grade-report-grader table#user-grades tr.even td.hmarked {
background-color:#ff9;
}

.grade-report-grader table#user-grades td.hmarked.vmarked,.grade-report-grader table#user-grades tr.odd td.hmarked.vmarked,.grade-report-grader table#user-grades td.hmarked.vmarked,.grade-report-grader table#user-grades tr.even td.hmarked.vmarked,.grade-report-grader table#user-grades tr.odd td.hmarked.vmarked {
background-color:#fc9;
}

.grade-report-grader table#user-grades tr.heading,.grade-report-grader table#user-grades .heading td {
border-style:solid;
border-width:0;
}

.grade-report-grader table#user-grades td.useridnumber,.grade-report-grader table#user-grades th,.grade-report-grader div.gradeparent,.ie6 form,.grade-report-grader table#user-grades td.ajax {
text-align:left;
}

.grade-report-grader table tr.avg td.cell,.grade-report-grader table#user-grades td.controls,.grade-report-grader table tr.avg,.grade-report-grader table tr.avg td,.grade-report-grader table tr.avg th {
background-color:#f3ead8;
}

.grade-report-grader div.left_scroller tr,.grade-report-grader div.right_scroller tr,.grade-report-grader div.left_scroller td,.grade-report-grader div.right_scroller td,.grade-report-grader div.left_scroller th,.grade-report-grader div.right_scroller th {
height:4em;
font-size:10px;
}

.grade-report-grader table th.user,.grade-report-grader table td.useridnumber {
text-align:left;
vertical-align:middle;
}

/*
.grade-report-grader .yui-overlay {
    background-color: #FFEE69;
    border-color: #D4C237 #A6982B #A6982B;
    border-style: solid;
    border-width: 1px;
    left: 0;
    padding: 2px 5px;
    font-size: 0.7em;
}
*/

.grade-report-grader .yui-overlay .fullname {
    color: #5F3E00;
    font-weight: bold;
}
.grade-report-grader .yui-overlay .itemname {
    color: #194F3E;
    font-weight: bold;
}
.grade-report-grader .yui-overlay .feedback {
    color: #5F595E;
}
/* .grade-report-grader table#user-grades td */
/* .grader-report-grader table#user-grades td .yui-panel div.hd { */
#tooltipPanel {
  text-align: left;
}


<?php include($CFG->dirroot.'/lib/yui/container/assets/skins/sam/container.css') ?>
.yui-skin-sam .yui-panel .hd{padding:0 10px;font-size:93%;line-height:2;*line-height:1.9;font-weight:bold;color:#000;background:url(<?php echo $CFG->wwwroot."/lib/yui" ?>/assets/skins/sam/sprite.png) repeat-x 0 -200px;}
.yui-skin-sam .container-close{border-color: #45c;position:absolute;top:5px;right:6px;width:25px;height:15px;background:url(<?php echo $CFG->wwwroot."/lib/yui" ?>/assets/skins/sam/sprite.png) no-repeat 0 -300px;cursor:pointer;}
.yui-skin-sam .yui-simple-dialog .bd .yui-icon{background:url(<?php echo $CFG->wwwroot."/lib/yui" ?>/assets/skins/sam/sprite.png) no-repeat 0 0;width:16px;height:16px;margin-right:10px;float:left;}

.grade-report-grader .yui-overlay a.container-close {
  margin-top: -3px;
}

#hiddentooltiproot, .tooltipDiv {
  display: none;
}

==> moodle-1.9.7.tbz: www/moodle/grade/report/grader/styles.php <==
.flexible th {
white-space:normal;
}

.gradestable th.user img {
width:20px;
height:20px;
}

.grade-report-grader table#user-grades .catlevel2 {
background-color:#f9f9f9;
}

.grade-report-grader table#user-grades td.overridden {
background-color:#ddd;
}

.grade-report-grader table#user-grades tr.avg td.cell {
background-color:#efefff;
font-weight:700;
color:#00008B;
}

.grade-report-grader table#user-grades tr.odd td.cell {
background-color:#efefef;
white-space:nowrap;
}

.grade-report-grader table#user-grades tr.even td.overridden {
background-color:#F3E4C0;
}

.grade-report-grader table#user-grades tr.odd td.overridden {
background-color:#EFD9A4;
}

.grade-report-grader table#user-grades tr.even td.excluded {
background-color:#EABFFF;
}

.grade-report-grader table#user-grades tr.odd td.excluded {
background-color:#E5AFFF;
}

.grade-report-grader table#user-grades tr.odd th.header {
background-color:#efefef;
background-image:none;
}

.grade-report-grader table#user-grades tr.groupavg td.cell {
background-color:#efffef;
font-weight:700;
color:#006400;
}

.grade-report-grader table#user-grades td.cat,.grade-report-grader table#user-grades td.course {
font-weight:700;
}

.grade-report-grader table#user-grades {
font-size:10px;
width:auto;
background-color:transparent;
border-style:solid;
border-width:1px;
margin:20px 0 0;
}

.grade-report-grader #overDiv table {
margin:0;
}

.grade-report-grader #overDiv table td.feedback {
border:0;
}

.grade-report-grader #overDiv .feedback {
font-size:70%;
background-color:#ABF;
color:#000;
font-family:Verdana;
font-weight:400;
}

.grade-report-grader #overDiv .caption {
font-size:70%;
background-color:#56C;
color:#CCF;
font-family:Arial;
font-weight:700;
}

.grade-report-grader #overDiv .intersection {
font-size:70%;
background-color:#ABF;
color:#000;
font-family:Verdana;
font-weight:400;
}

.grade-report-grader #overDiv .intersectioncaption {
background-color:#56C;
color:#CCF;
font-family:Arial;
font-weight:700;
}

.grade-report-grader div.submit {
margin-top:20px;
text-align:center;
}

.grade-report-grader table#user-grades td {
text-align:right;
border-style:solid;
border-width:0 1px 1px 0;
}

.grade-report-grader table#user-grades th.category {
vertical-align:top;
border-style:solid;
border-width:1px 1px 0;
}

.grade-report-grader table#user-grades th.user {
text-align:left;
border-style:solid;
border-width:0 0 1px;
}

.grade-report-grader table#user-grades th.useridnumber {
border-style:solid;
border-width:0 0 1px 1px;
}

.grade-report-grader table#user-grades th.categoryitem,.grade-report-grader table#user-grades th.courseitem,.grade-report-grader table#user-grades td.topleft {
vertical-align:top;
border-style:solid;
border-width:0 1px;
}

/* we don't want 25px height - at all
 * This causes the columns to fall out of line if Static Students Column is enabled
.grade-report-grader table#user-grades th.category,
.grade-report-grader table#user-grades th.item,
.grade-report-grader table#user-grades th.categoryitem,
.grade-report-grader table#user-grades th.courseitem {
height: 25px;
}
*/

.grade-report-grader td,.grade-report-grader th {
border-color:#CECECE;
}

.grade-report-grader table#participants th {
vertical-align:top;
width:auto;
}

.grade-report-grader table#user-grades td.fillerfirst {
border-style:solid;
border-width:0 0 0 1px;
}

.grade-report-grader table#user-grades td.fillerlast {
border-style:solid;
border-width:0 1px 0 0;
}

.grade-report-grader table#user-grades th.item ,
.grade-report-grader table#user-grades th.categoryitem ,
.grade-report-grader table#user-grades th.courseitem {
border-bottom-color:#000;
vertical-align:top;
border-style:solid;
border-width:1px;
}

.grade-report-grader div.gradertoggle {
display:inline;
margin-left:20px;
}

.grade-report-grader table#user-grades th.range {
text-align:right;
border-style:solid;
border-width:1px;
}

.grade-report-grader table#user-grades .userpic {
display:inline;
margin-right:10px;
}

.grade-report-grader table#user-grades .quickfeedback {
border:#000 1px dashed;
}

.grade-report-grader #siteconfiglink {
text-align:right;
}

.grade-report-grader table#user-grades .hidden,.grade-report-grader table#user-grades .hidden a {
color:#aaa;
}

.grade-report-grader table#user-grades .datesubmitted {
font-size:.7em;
}

.grade-report-grader table#user-grades td.cell {
padding-left:5px;
padding-right:5px;
vertical-align:middle;
}

.grade-report-grader table {
border-collapse:collapse;
background-color:#fff;
font-size:10px;
border-color:#cecece;
}

.grade-report-grader th {
padding:2px 10px 0;
}

.grade-report-grader span.inclusion-links {
margin:0 5px 0 10px;
}

.grade-report-grader table#user-grades .item {
background-color:#e9e9e9;
}

.grade-report-grader table tr.odd th.header {
background-color:#efefef;
background-image:none;
border-width:0 0 1px;
}

.grade-report-grader table tr.heading th.header {
border-top:1px solid #cecece;
}

.grade-report-grader table#user-grades tr.heading th.categoryitem,.grade-report-grader table#user-grades tr.heading th.courseitem {
border-width:0 0 0 1px;
}

.grade-report-grader table#user-grades th.category.header.catlevel1 {
vertical-align:top;
border-style:solid;
border-width:1px 1px 0 0;
}

.grade-report-grader div.left_scroller th.user a {
vertical-align:middle;
margin:0;
padding:0;
}

.grade-report-grader table#user-grades th.categoryitem,.grade-report-grader table#user-grades th.courseitem,.grade-report-grader table td.topleft {
vertical-align:top;
border-color:#cecece #cecece #000;
border-style:solid;
border-width:0 1px 1px;
}

.grade-report-grader table td.topleft {
border-bottom:none;
}

.grade-report-grader table#user-grades td.topleft {
background-color:#fff;
}

.grade-report-grader div.userpic {
margin-right:10px;
float:left;
}

.grade-report-grader div.userpic img {
border:3px double #cecece;
vertical-align:middle;
width:2.7em;
height:2.7em;
}

.grade-report-grader a.quickedit {
line-height:1em;
display:block;
float:right;
clear:none;
font-size:9px;
background-color:transparent;
margin:.1em 0 0;
}

.grade-report-grader a.quickedit2 {
display:block;
float:right;
clear:none;
background-color:transparent;
margin:1.3em 0 0;
}

.grade-report-grader table#quick_edit {
border:1px solid #cecece;
margin:0 auto;
}

.grade-report-grader table#quick_edit td {
vertical-align:middle;
border:1px solid #cecece;
text-align:left;
margin:0;
padding:5px;
}

.grade-report-grader table#quick_edit td img {
border:3px double #cecece;
vertical-align:middle;
padding:0;
}

.grade-report-grader td input {
border:1px solid #666;
margin-left:10px;
margin-right:10px;
}

.grade-report-grader table#quick_edit td.fullname {
border-left:none;
padding-left:5px;
}

.grade-report-grader table#quick_edit td.picture {
border-right:none;
}

.grade-report-grader table#quick_edit td.finalgrade input {
width:5em;
}

.grade-report-grader h1 {
text-align:center;
clear:both;
}

.grade-report-grader form {
text-align:center;
}

.grade-report-grader input.center {
margin:10px auto 0;
}

.grade-report-grader .lefttbody {
width:auto;
vertical-align:middle;
}

.grade-report-grader table#user-grades th.fixedcolumn {
border:1px solid #cecece;
vertical-align:middle;
}

.grade-report-grader table#fixed_column th {
border:1px solid #cecece;
vertical-align:middle;
border-right-color:#000;
}

.grade-report-grader table#fixed_column th.user{
border-right-color:#cecece;
}

.grade-report-grader table#fixed_column {
padding-top:20px;
border-top:1px solid #cecece;
background-color:#fff;
}

.grade-report-grader .left_scroller {
float:left;
clear:none;
padding-top:20px;
}

.grade-report-grader .right_scroller {
width:auto;
clear:none;
overflow-x:auto;
}

.grade-report-grader table tr.avg,.grade-report-grader table tr.groupavg td,.grade-report-grader table tr.avg td,.grade-report-grader table tr.groupavg th,.grade-report-grader table tr.avg th,.grade-report-grader table tr.controls_row,.grade-report-grader table tr.controls_row th,.grade-report-grader table tr.range_row,.grade-report-grader table tr.range_row th,div.right_scroller tr {
height:2em;
}

.grade-report-grader table#user-grades tr.groupavg td.cell,.grade-report-grader tr.groupavg th.header {
background-color:#efffef;
}

.grade-report-grader form td.excluded {
color:red;
}

.grade-report-grader .excludedfloater {
font-weight:700;
color:red;
font-size:9px;
float:left;
}

.grade-report-grader span.gradepass {
color:#298721;
}

.grade-report-grader span.gradefail {
color:#890d0d;
}

.gradeweight {
color:#461d7c;
font-weight:700;
}

.grade-report-grader td select {
font-size:100%;
padding:0;
}

.grade-report-grader .righttest td select {
font-size:86%;
padding:0;
}

.grade-report-grader tr.avg,tr.controls,td.controls,th.controls,.grade-report-grader tr.groupavg,tr.range,th.range,td.range,tr.heading th.range {
height:2.8em!important;
white-space:nowrap;
}
.heading_name_row th {
white-space:nowrap;
width:2000px;
}

.grade_icons img.ajax {
float:right;
}

.gradestable th.user,.gradestable th.range,.grade-report-grader .flexible th,.grade-report-grader .flexible td,.grade-report-grader .flexible th a,.grade-report-grader .flexible td a,.grade-report-grader .gradestable th.range,.grade-report-grader td {
white-space:nowrap;
}

.grade-report-grader table#user-grades .catlevel1,.grade-report-grader .r1,.grade-report-grader table tr.even td.cell,.grade-report-grader table tr.even th {
background-color:#fff;
}

.grade-report-grader table#user-grades .catlevel3,.grade-report-grader table tr.odd td.cell {
background-color:#efefef;
}

.grade-report-grader table#fixed_column tr.odd th ,
.grade-report-grader table#user-grades tr.odd th {
background-color:#efefef;
}

.grade-report-grader table#user-grades td.vmarked,.grade-report-grader table#user-grades tr.odd td.vmarked,.grade-report-grader table#user-grades td.vmarked,.grade-report-grader table#user-grades tr.odd td.vmarked,.grade-report-grader table#user-grades tr.even td.vmarked {
background-color:#fc3;
}

.grade-report-grader table#user-grades td.hmarked,.grade-report-grader table#user-grades tr.odd td.hmarked,.grade-report-grader table#user-grades td.hmarked,.grade-report-grader table#user-grades tr.odd td.hmarked,.grade-report-grader table#user-grades tr.even td.hmarked {
background-color:#ff9;
}

.grade-report-grader table#user-grades td.hmarked.vmarked,.grade-report-grader table#user-grades tr.odd td.hmarked.vmarked,.grade-report-grader table#user-grades td.hmarked.vmarked,.grade-report-grader table#user-grades tr.even td.hmarked.vmarked,.grade-report-grader table#user-grades tr.odd td.hmarked.vmarked {
background-color:#fc9;
}

.grade-report-grader table#user-grades tr.heading,.grade-report-grader table#user-grades .heading td {
border-style:solid;
border-width:0;
}

.grade-report-grader table#user-grades td.useridnumber,.grade-report-grader table#user-grades th,.grade-report-grader div.gradeparent,.grade-report-grader table#user-grades td.ajax {
text-align:left;
}

.grade-report-grader table tr.avg td.cell,.grade-report-grader table#user-grades td.controls,.grade-report-grader table tr.avg,.grade-report-grader table tr.avg td,.grade-report-grader table tr.avg th {
background-color:#f3ead8;
}

.grade-report-grader div.left_scroller tr,.grade-report-grader div.right_scroller tr,.grade-report-grader div.left_scroller td,.grade-report-grader div.right_scroller td,.grade-report-grader div.left_scroller th,.grade-report-grader div.right_scroller th {
height:4.4em;
font-size:10px;
}

.grade-report-grader table th.user,.grade-report-grader table td.useridnumber {
text-align:left;
vertical-align:middle;
}

/*
.grade-report-grader .yui-overlay {
    background-color: #FFEE69;
    border-color: #D4C237 #A6982B #A6982B;
    border-style: solid;
    border-width: 1px;
    left: 0;
    padding: 2px 5px;
    font-size: 0.7em;
}
*/

.grade-report-grader .yui-overlay .fullname {
    color: #5F3E00;
    font-weight: bold;
}
.grade-report-grader .yui-overlay .itemname {
    color: #194F3E;
    font-weight: bold;
}
.grade-report-grader .yui-overlay .feedback {
    color: #5F595E;
}
/* .grade-report-grader table#user-grades td */
/* .grader-report-grader table#user-grades td .yui-panel div.hd { */
#tooltipPanel {
  text-align: left;
}


<?php include($CFG->dirroot.'/lib/yui/container/assets/skins/sam/container.css') ?>
.yui-skin-sam .yui-panel .hd{padding:0 10px;font-size:93%;line-height:2;*line-height:1.9;font-weight:bold;color:#000;background:url(<?php echo $CFG->wwwroot."/lib/yui" ?>/assets/skins/sam/sprite.png) repeat-x 0 -200px;}
.yui-skin-sam .container-close{border-color: #45c;position:absolute;top:5px;right:6px;width:25px;height:15px;background:url(<?php echo $CFG->wwwroot."/lib/yui" ?>/assets/skins/sam/sprite.png) no-repeat 0 -300px;cursor:pointer;}
.yui-skin-sam .yui-simple-dialog .bd .yui-icon{background:url(<?php echo $CFG->wwwroot."/lib/yui" ?>/assets/skins/sam/sprite.png) no-repeat 0 0;width:16px;height:16px;margin-right:10px;float:left;}

.grade-report-grader .yui-overlay a.container-close {
  margin-top: -3px;
}

#hiddentooltiproot, .tooltipDiv {
  display: none;
}
